@@ -1,18 +1,23 @@
 import Base.Multimedia.display
 
-type RmdDisplay <: Display
+struct RmdDisplay <: Display
 end
 
+const begin_plot_in_R = R"JuliaCall:::begin_plot"
+const finish_plot_in_R = R"JuliaCall:::finish_plot"
+
 function plot_display(display::RmdDisplay, x)
-    path = rcopy(R"JuliaCall:::begin_plot()")
+    path = rcopy(begin_plot_in_R())
     mkpath(dirname(path))
     Main.Plots.savefig(x, path)
-    R"JuliaCall:::finish_plot()"
+    finish_plot_in_R()
 end
 
+const text_display_in_R = R"JuliaCall:::text_display"
+
 function text_display(display::RmdDisplay, x)
     s = limitstringmime(MIME("text/plain"), x)
-    R"JuliaCall:::text_display"(s)
+    text_display_in_R(s)
 end
 
 function display(display::RmdDisplay, x)
@@ -21,12 +26,14 @@ function display(display::RmdDisplay, x)
             plot_display(display, x)
             return
         end
+    catch e;
     end
     try
         text_display(display, x)
         return
+    catch e;
     end
     throw(MethodError)
 end
 
-rmd_display = RmdDisplay()
+const rmd_display = RmdDisplay()
