@@ -3,19 +3,37 @@
 ## <https://github.com/Non-Contradiction/JuliaCall/issues/9>
 ## as well as coming up with the solution
 
-if Pkg.installed("Suppressor") == nothing
-    Pkg.add("Suppressor")
-end;
-
-using Suppressor
-
 CurrentRhome = ARGS[1]
 
 ## println(Rhome)
 
 ENV["R_HOME"] = CurrentRhome
 
-if Pkg.installed("RCall") == nothing
+const julia07 = VERSION > v"0.6.5"
+
+if julia07
+    using Pkg
+else
+    macro pkg_str(x) begin nothing end end
+end
+
+function installed(name)
+    @static if julia07
+        get(Pkg.installed(), name, nothing)
+    else
+        Pkg.installed(name)
+    end
+end
+
+if installed("Suppressor") == nothing
+    Pkg.add("Suppressor")
+end;
+
+using Suppressor
+
+if julia07
+    pkg"add RCall#e59a546"
+elseif installed("RCall") == nothing
     Pkg.add("RCall")
 end;
 
@@ -31,7 +49,7 @@ else
     using RCall
 
     if RCall.Rhome != CurrentRhome
-        if Pkg.installed("RCall") >= v"0.10.2"
+        if installed("RCall") >= v"0.10.2"
             Pkg.build("RCall")
         else
             Base.compilecache("RCall")
